/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "XPathNSResolver.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomDOMObject.h"
#include "gdom/GdomXPathNSResolver.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomXPathNSResolver.h"
#include "gdom/PrivateIntGdomXPathNSResolver.h"
#include "glib-object.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
gpointer toGDOM(WebCore::XPathNSResolver* obj)
{
    return WebCore::cacheDOMObject<WebCore::XPathNSResolver, GDOMXPathNSResolver>(obj);
}
} /* namespace WebCore */
extern "C" {

GDOMXPathNSResolver::GDOMXPathNSResolver(PassRefPtr<WebCore::XPathNSResolver> impl)
    : GDOMObject()
    , m_impl(impl)
{
}

GDOMXPathNSResolver::~GDOMXPathNSResolver()
{
    m_impl.get()->deref();
    WebCore::GDOMScriptInterpreter::forgetDOMObject(m_impl.get());

}

gchar *
gdom_x_path_ns_resolver_lookup_namespace_uri (GdomXPathNSResolver *thiz, gchar * prefix)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::XPathNSResolver * item = (gdom_x_path_ns_resolver_get_private(thiz));
    g_return_val_if_fail (item, 0);
    g_return_val_if_fail (prefix, 0);
    WebCore::String _g_prefix = WebCore::String::fromUTF8(prefix);
    gchar * res = _G_GET_UTF8(item->lookupNamespaceURI(_g_prefix));
    return res;

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "XPathNSResolver.h"
#include <gdom/GdomXPathNSResolver.h>
#include <gdom/PrivateGdomXPathNSResolver.h>
#include <gdom/PrivateIntGdomXPathNSResolver.h>
#include <gdom/GdomXPathNSResolverprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomXPathNSResolver, gdom_x_path_ns_resolver, GDOM_TYPE_DOM_OBJECT);

/*
struct _GdomXPathNSResolverPrivate {
    class WebCore::XPathNSResolver *item;
};

#define GDOM_X_PATH_NS_RESOLVER_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_X_PATH_NS_RESOLVER, GdomXPathNSResolverPrivate))
*/
G_END_DECLS
WebCore::XPathNSResolver *
gdom_x_path_ns_resolver_get_private(GdomXPathNSResolver *request)
{
    GDOMXPathNSResolver *res;
    res = static_cast<GDOMXPathNSResolver*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::XPathNSResolver*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
};


static void gdom_x_path_ns_resolver_finalize(GObject* object)
{
    /*GdomXPathNSResolver* request = GDOM_X_PATH_NS_RESOLVER(object);*/
    /*GdomXPathNSResolverPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_DOM_OBJECT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_x_path_ns_resolver_parent_class)->finalize(object);
}

static void gdom_x_path_ns_resolver__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomXPathNSResolver *self = GDOM_X_PATH_NS_RESOLVER(object);
    WebCore::XPathNSResolver * gself = (gdom_x_path_ns_resolver_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_x_path_ns_resolver__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomXPathNSResolver *self = GDOM_X_PATH_NS_RESOLVER(object);
    WebCore::XPathNSResolver * gself = (gdom_x_path_ns_resolver_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_x_path_ns_resolver_class_init(GdomXPathNSResolverClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_x_path_ns_resolver_finalize;
    g_klass->set_property = gdom_x_path_ns_resolver__set_property_fn;
    g_klass->get_property = gdom_x_path_ns_resolver__get_property_fn;





    /*g_type_class_remove_private(requestClass, sizeof(GdomXPathNSResolverPrivate));*/
}

static void gdom_x_path_ns_resolver_init(GdomXPathNSResolver* request)
{
    /*GdomXPathNSResolverPrivate* priv = GDOM_X_PATH_NS_RESOLVER_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

